# New in 0.17.2 (2022-08-26)

## Changes

-   Move `training` argument in {class}`~scvi.module.JaxVAE` constructor to a keyword argument into the call method. This simplifies the {class}`~scvi.module.base.JaxModuleWrapper` logic and avoids the reinstantiation of {class}`~scvi.module.JaxVAE` during evaluation [#1580].
-   Add a static method on the BaseModelClass to return the AnnDataManger's full registry [#1617].
-   Clarify docstrings for continuous and categorical covariate keys [#1637].
-   Remove poetry lock, use newer build system [#1645].

## Bug Fixes

-   Fix CellAssign to accept extra categorical covariates [#1629].
-   Fix an issue where `max_epochs` is never determined heuristically for totalvi, instead it would always default to 400 [#1639].

## Breaking Changes

-   Fix an issue where `max_epochs` is never determined heuristically for totalvi, instead it would always default to 400 [#1639].

## Contributors

-   [@watiss]
-   [@RK900]
-   [@adamgayoso]
-   [@jjhong922]

[#1580]: https://github.com/scverse/scvi-tools/pull/1580
[#1617]: https://github.com/scverse/scvi-tools/pull/1617
[#1629]: https://github.com/scverse/scvi-tools/pull/1629
[#1637]: https://github.com/scverse/scvi-tools/pull/1637
[#1639]: https://github.com/scverse/scvi-tools/pull/1639
[#1645]: https://github.com/scverse/scvi-tools/pull/1645
[@watiss]: https://github.com/watiss
[@rk900]: https://github.com/RK900
[@adamgayoso]: https://github.com/adamgayoso
[@jjhong922]: https://github.com/jjhong922
